@@ -154,10 +154,9 @@ describe 'neutron::plugins::ml2' do
 
     context 'configure ml2 with bad driver value' do
       before :each do
+       scope.expects(:warning).with('type_driver unknown.')
        params.merge!(:type_drivers => ['foobar'])
       end
-
-      it_raises 'a Puppet::Error', /type_driver unknown./
     end
 
     context 'when using flat driver' do
